import { utils, BigNumberish, BytesLike, BigNumber, BaseContract, Signer, Overrides, ContractTransaction, CallOverrides, PopulatedTransaction } from 'ethers';
import { FunctionFragment, Result, EventFragment } from '@ethersproject/abi';
import { Provider, Listener } from '@ethersproject/providers';
import { TypedEvent, TypedEventFilter, TypedListener, OnEvent } from './common.js';

interface IByocRegistryInterface extends utils.Interface {
    contractName: string | "IByocRegistry";
    functions: {
        "approveOperator(address,bool)": FunctionFragment;
        "getAllPublishedContracts(address)": FunctionFragment;
        "getPublishedContract(address,uint256)": FunctionFragment;
        "getPublishedContractGroup(address,bytes32)": FunctionFragment;
        "isApprovedByPublisher(address,address)": FunctionFragment;
        "publishContract(address,string,bytes32,address,bytes32)": FunctionFragment;
        "unpublishContract(address,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "approveOperator", values: [string, boolean]): string;
    encodeFunctionData(functionFragment: "getAllPublishedContracts", values: [string]): string;
    encodeFunctionData(functionFragment: "getPublishedContract", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPublishedContractGroup", values: [string, BytesLike]): string;
    encodeFunctionData(functionFragment: "isApprovedByPublisher", values: [string, string]): string;
    encodeFunctionData(functionFragment: "publishContract", values: [string, string, BytesLike, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "unpublishContract", values: [string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "approveOperator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllPublishedContracts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPublishedContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPublishedContractGroup", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isApprovedByPublisher", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "publishContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unpublishContract", data: BytesLike): Result;
    events: {
        "Approved(address,address,bool)": EventFragment;
        "ContractPublished(address,address,uint256,tuple)": EventFragment;
        "ContractUnpublished(address,address,uint256)": EventFragment;
        "Paused(bool)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Approved"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ContractPublished"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ContractUnpublished"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Paused"): EventFragment;
}
declare type ApprovedEvent = TypedEvent<[
    string,
    string,
    boolean
], {
    publisher: string;
    operator: string;
    isApproved: boolean;
}>;
declare type ApprovedEventFilter = TypedEventFilter<ApprovedEvent>;
declare type ContractPublishedEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    IByocRegistry.CustomContractStructOutput
], {
    operator: string;
    publisher: string;
    contractId: BigNumber;
    publishedContract: IByocRegistry.CustomContractStructOutput;
}>;
declare type ContractPublishedEventFilter = TypedEventFilter<ContractPublishedEvent>;
declare type ContractUnpublishedEvent = TypedEvent<[
    string,
    string,
    BigNumber
], {
    operator: string;
    publisher: string;
    contractId: BigNumber;
}>;
declare type ContractUnpublishedEventFilter = TypedEventFilter<ContractUnpublishedEvent>;
declare type PausedEvent = TypedEvent<[boolean], {
    isPaused: boolean;
}>;
declare type PausedEventFilter = TypedEventFilter<PausedEvent>;
declare namespace IByocRegistry {
    type CustomContractStruct = {
        contractId: BigNumberish;
        groupId: BytesLike;
        publishMetadataUri: string;
        bytecodeHash: BytesLike;
        implementation: string;
    };
    type CustomContractStructOutput = [
        BigNumber,
        string,
        string,
        string,
        string
    ] & {
        contractId: BigNumber;
        groupId: string;
        publishMetadataUri: string;
        bytecodeHash: string;
        implementation: string;
    };
}
interface IByocRegistry extends BaseContract {
    contractName: string | "IByocRegistry";
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: IByocRegistryInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        approveOperator(operator: string, toApprove: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        getAllPublishedContracts(publisher: string, overrides?: CallOverrides): Promise<[
            IByocRegistry.CustomContractStructOutput[]
        ] & {
            published: IByocRegistry.CustomContractStructOutput[];
        }>;
        getPublishedContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<[
            IByocRegistry.CustomContractStructOutput
        ] & {
            published: IByocRegistry.CustomContractStructOutput;
        }>;
        getPublishedContractGroup(publisher: string, groupId: BytesLike, overrides?: CallOverrides): Promise<[
            IByocRegistry.CustomContractStructOutput[]
        ] & {
            published: IByocRegistry.CustomContractStructOutput[];
        }>;
        isApprovedByPublisher(publisher: string, operator: string, overrides?: CallOverrides): Promise<[boolean] & {
            isApproved: boolean;
        }>;
        publishContract(publisher: string, publishMetadataUri: string, bytecodeHash: BytesLike, implementation: string, groupId: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        unpublishContract(publisher: string, contractId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    approveOperator(operator: string, toApprove: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    getAllPublishedContracts(publisher: string, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput[]>;
    getPublishedContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput>;
    getPublishedContractGroup(publisher: string, groupId: BytesLike, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput[]>;
    isApprovedByPublisher(publisher: string, operator: string, overrides?: CallOverrides): Promise<boolean>;
    publishContract(publisher: string, publishMetadataUri: string, bytecodeHash: BytesLike, implementation: string, groupId: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    unpublishContract(publisher: string, contractId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        approveOperator(operator: string, toApprove: boolean, overrides?: CallOverrides): Promise<void>;
        getAllPublishedContracts(publisher: string, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput[]>;
        getPublishedContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput>;
        getPublishedContractGroup(publisher: string, groupId: BytesLike, overrides?: CallOverrides): Promise<IByocRegistry.CustomContractStructOutput[]>;
        isApprovedByPublisher(publisher: string, operator: string, overrides?: CallOverrides): Promise<boolean>;
        publishContract(publisher: string, publishMetadataUri: string, bytecodeHash: BytesLike, implementation: string, groupId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        unpublishContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Approved(address,address,bool)"(publisher?: string | null, operator?: string | null, isApproved?: null): ApprovedEventFilter;
        Approved(publisher?: string | null, operator?: string | null, isApproved?: null): ApprovedEventFilter;
        "ContractPublished(address,address,uint256,tuple)"(operator?: string | null, publisher?: string | null, contractId?: BigNumberish | null, publishedContract?: null): ContractPublishedEventFilter;
        ContractPublished(operator?: string | null, publisher?: string | null, contractId?: BigNumberish | null, publishedContract?: null): ContractPublishedEventFilter;
        "ContractUnpublished(address,address,uint256)"(operator?: string | null, publisher?: string | null, contractId?: BigNumberish | null): ContractUnpublishedEventFilter;
        ContractUnpublished(operator?: string | null, publisher?: string | null, contractId?: BigNumberish | null): ContractUnpublishedEventFilter;
        "Paused(bool)"(isPaused?: null): PausedEventFilter;
        Paused(isPaused?: null): PausedEventFilter;
    };
    estimateGas: {
        approveOperator(operator: string, toApprove: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        getAllPublishedContracts(publisher: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPublishedContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getPublishedContractGroup(publisher: string, groupId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        isApprovedByPublisher(publisher: string, operator: string, overrides?: CallOverrides): Promise<BigNumber>;
        publishContract(publisher: string, publishMetadataUri: string, bytecodeHash: BytesLike, implementation: string, groupId: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        unpublishContract(publisher: string, contractId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        approveOperator(operator: string, toApprove: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        getAllPublishedContracts(publisher: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPublishedContract(publisher: string, contractId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPublishedContractGroup(publisher: string, groupId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isApprovedByPublisher(publisher: string, operator: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        publishContract(publisher: string, publishMetadataUri: string, bytecodeHash: BytesLike, implementation: string, groupId: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        unpublishContract(publisher: string, contractId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}

export { ApprovedEvent, ApprovedEventFilter, ContractPublishedEvent, ContractPublishedEventFilter, ContractUnpublishedEvent, ContractUnpublishedEventFilter, IByocRegistry, IByocRegistryInterface, PausedEvent, PausedEventFilter };
